Index: /trunk/SophyaPI/PI/piaxes.h
===================================================================
--- /trunk/SophyaPI/PI/piaxes.h	(revision 2348)
+++ /trunk/SophyaPI/PI/piaxes.h	(revision 2349)
@@ -12,5 +12,5 @@
 
 enum {
-  kStdAxes     = 0x0001,
+  kCentAxes    = 0x0001,
   kBoxAxes     = 0x0002,
   kTicks       = 0x0004,
@@ -21,6 +21,8 @@
   kLabels      = 0x1000,
   kGridOn      = 0x2000,
-  kAxesDflt    = kStdAxes | kTicks | kLabels,       // Axes trace par defaut
-  kAxesNone    = 0                                  // Pas de trace d axe  
+// Axes trace par defaut
+  kAxesDflt    = kBoxAxes | kTicks | kMajTicks | kIntTicks | kLabels,       
+  kStdAxes     = kAxesDflt,       
+  kAxesNone    = 0         // Pas de trace d axe  
 };
 
@@ -33,10 +35,10 @@
 
   virtual void      DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, 
-			       unsigned int flags, bool afsz);
+			       unsigned int flags=kAxesDflt, bool afsz=true);
 
   virtual void      DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, 
-			       unsigned int flags, bool afsz, 
 			       double xmin, double xmax, 
-			       double ymin, double ymax);
+			       double ymin, double ymax,
+			       unsigned int flags=kAxesDflt, bool afsz=true);
 
 
@@ -45,4 +47,9 @@
   virtual void      DrawYCaption(PIGraphicUC* g, PIGraphicAtt& att, unsigned int flags,
 				 string const& YLabel); 
+
+  //  Taille des ticks d'axes (en fraction de taille d'axe)
+  void  ConfigureTicks(int ntickx=10, int nticky=12, 
+		       double majtl=0.0125, double mintl=0.007);
+  void  ConfigureAutoFontSize(double fszf=0.04);
 
   //  virtual void      DrawHorizontalAxe(double xmin, double xmax, double y, 
@@ -80,4 +87,7 @@
   bool   axesAFSz;
   
+  int xNTicks, yNTicks;             // Nb de ticks en X, Y
+  double fMajTickLen, fMinTickLen;  // Taille des ticks, en fraction de Max-Min
+  double fontSz;                    // Taille pour autofontsize, frac Max-Min
   vector<double> xMajTicks;
   vector<double> xMinTicks;
Index: /trunk/SophyaPI/PI/piaxestools.cc
===================================================================
--- /trunk/SophyaPI/PI/piaxestools.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/piaxestools.cc	(revision 2349)
@@ -230,5 +230,5 @@
   if (scd->GetAxesFlags() & kGridOn) mCkb[2]->SetState(true);
   else mCkb[2]->SetState(false);
-  if (scd->GetAxesFlags() & kStdAxes) mCkb[5]->SetState(true);
+  if (scd->GetAxesFlags() & kCentAxes) mCkb[5]->SetState(true);
   else mCkb[5]->SetState(false);
   if (scd->GetAxesFlags() & kMinTicks) mCkb[6]->SetState(true);
@@ -303,6 +303,6 @@
   if (mCkb[2]->GetState()) flags |= kGridOn;
   else  flags &= ~kGridOn;
-  if (mCkb[5]->GetState()) { flags |= kStdAxes;  flags &= ~kBoxAxes; }
-  else { flags &= ~kStdAxes;  flags |= kBoxAxes; }
+  if (mCkb[5]->GetState()) { flags |= kCentAxes;  flags &= ~kBoxAxes; }
+  else { flags &= ~kCentAxes;  flags |= kBoxAxes; }
   if (mCkb[6]->GetState()) flags |= kMinTicks;
   else  flags &= ~kMinTicks;
Index: /trunk/SophyaPI/PI/pidrawer.cc
===================================================================
--- /trunk/SophyaPI/PI/pidrawer.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/pidrawer.cc	(revision 2349)
@@ -430,10 +430,10 @@
 {
   axesFlags = flags;
-  if (axesFlags & (kIntTicks | kExtTicks | kMajTicks | kMinTicks))
-    axesFlags |= kTicks;
-  if ((axesFlags & (kTicks | kIntTicks | kExtTicks)) == kTicks)
-    axesFlags |= kIntTicks | kExtTicks;
-  if ((axesFlags & (kTicks | kMajTicks | kMinTicks)) == kTicks)
-    axesFlags |= kMajTicks;
+  //  if (axesFlags & (kIntTicks | kExtTicks | kMajTicks | kMinTicks))
+  //    axesFlags |= kTicks;
+  //  if ((axesFlags & (kTicks | kIntTicks | kExtTicks)) == kTicks)
+  //    axesFlags |= kIntTicks | kExtTicks;
+  //  if ((axesFlags & (kTicks | kMajTicks | kMinTicks)) == kTicks)
+  //    axesFlags |= kMajTicks;
 }
 
@@ -444,5 +444,6 @@
   g->NoClip();
   PIAxes axes;
-  axes.DrawXYAxes(g, mGrAtt, axesFlags, axesAFSz, XMin(), XMax(), YMin(), YMax()); 
+  axes.DrawXYAxes(g, mGrAtt, XMin(), XMax(), YMin(), YMax(),
+		  axesFlags, axesAFSz); 
   g->Clip();
 }
Index: /trunk/SophyaPI/PI/pieldrw.cc
===================================================================
--- /trunk/SophyaPI/PI/pieldrw.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/pieldrw.cc	(revision 2349)
@@ -524,19 +524,19 @@
     string opts = opt[k];
     if ( (opts == "stdaxes") || (opts == "defaxes") || (opts == "boxaxes") )
-      SetAxesFlags(kBoxAxes | kExtTicks | kLabels);
+      SetAxesFlags(kAxesDflt);
     else if (opts == "boxaxesgrid")
-      SetAxesFlags(kBoxAxes | kExtTicks | kLabels | kGridOn);
+      SetAxesFlags(kAxesDflt | kGridOn);
     else if (opts == "fineaxes") 
-      SetAxesFlags(kBoxAxes | kTicks | kLabels | kMinTicks | kMajTicks);
+      SetAxesFlags(kAxesDflt | kMinTicks | kMajTicks);
     else if (opts == "fineaxesgrid")
-      SetAxesFlags(kBoxAxes | kTicks | kLabels | kMinTicks | kMajTicks | kGridOn);
+      SetAxesFlags(kAxesDflt | kMinTicks | kMajTicks | kGridOn);
     else if (opts == "centeredaxes")
-      SetAxesFlags(kStdAxes | kMajTicks | kLabels);
+      SetAxesFlags(kCentAxes | kMajTicks | kLabels);
     else if (opts == "finecenteredaxes")
-      SetAxesFlags(kStdAxes | kMajTicks | kMinTicks | kLabels);
+      SetAxesFlags(kCentAxes | kMajTicks | kMinTicks | kLabels);
     else if (opts == "centeredaxesgrid")
-      SetAxesFlags(kStdAxes | kMajTicks | kLabels | kGridOn);
+      SetAxesFlags(kCentAxes | kMajTicks | kLabels | kGridOn);
     else if (opts == "finecenteredaxesgrid")
-      SetAxesFlags(kStdAxes | kMajTicks | kMinTicks | kLabels | kGridOn);
+      SetAxesFlags(kCentAxes | kMajTicks | kMinTicks | kLabels | kGridOn);
     else if (opts == "axesnone")
       SetAxesFlags(kAxesNone);
@@ -554,18 +554,36 @@
       SetAxesFlags(GetAxesFlags() & ~kMinTicks);
     else if (opts == "extticks")
-      SetAxesFlags(GetAxesFlags() | kExtTicks);
+      SetAxesFlags(GetAxesFlags() & ~kIntTicks |  kExtTicks);
     else if (opts == "intticks")
-      SetAxesFlags(GetAxesFlags() | kIntTicks);
+      SetAxesFlags(GetAxesFlags() & ~kExtTicks |  kIntTicks);
+    else if (opts == "extintticks")
+      SetAxesFlags(GetAxesFlags() | kIntTicks |  kExtTicks);
     else if (opts == "grid")
       SetAxesFlags(GetAxesFlags() | kGridOn);
     else if (opts == "nogrid")
       SetAxesFlags(GetAxesFlags() & ~kGridOn);
-    else if (opts == "autofontsize")
+
+    else if (opts.substr(0,13) == "autofontsize=") {
+      double fszf = atof(opts.substr(13).c_str());
+      ConfigureAxeAutoFontSize(fszf);
       SetAxesAutoFontSize(true);
+    }
     else if (opts == "fixedfontsize")
       SetAxesAutoFontSize(false);
+
     else if (opts == "title" || opts == "tit") ShowTitles(true);
     else if (opts == "notitle" || opts == "notit") ShowTitles(false);
-
+    else if (opts.substr(0,8) == "nbticks=") {
+      int xnticks=0;
+      int ynticks=0;
+      sscanf(opts.substr(8).c_str(),"%d,%d", &xnticks, &ynticks);
+      ConfigureAxeTicks(xnticks, ynticks, 0., 0.);
+    }
+    else if (opts.substr(0,9) == "tickslen=") {
+      double fmajtl = 0.;
+      double fmintl = 0.;
+      sscanf(opts.substr(9).c_str(),"%lg,%lg", &fmajtl, &fmintl);
+      ConfigureAxeTicks(0, 0, fmajtl, fmintl);
+    }
     else {
       ndec--;
@@ -584,10 +602,10 @@
   //  g->NoClip();
   g->SaveGraphicAtt();
-  PIAxes axes;
-  axes.DrawXYAxes(g, mGrAtt, axesFlags, axesAFSz, XMin(), XMax(), YMin(), YMax()); 
+  axeDr.DrawXYAxes(g, mGrAtt, XMin(), XMax(), YMin(), YMax(), 
+		   axesFlags, axesAFSz); 
   g->RestoreGraphicAtt();
   if (showAxesLabels) { 
-    axes.DrawXCaption(g, labelAtt, axesFlags, xLabel);
-    axes.DrawYCaption(g, labelAtt, axesFlags, yLabel);
+    axeDr.DrawXCaption(g, labelAtt, axesFlags, xLabel);
+    axeDr.DrawYCaption(g, labelAtt, axesFlags, yLabel);
   }
   //  g->Clip();
Index: /trunk/SophyaPI/PI/pieldrw.h
===================================================================
--- /trunk/SophyaPI/PI/pieldrw.h	(revision 2348)
+++ /trunk/SophyaPI/PI/pieldrw.h	(revision 2349)
@@ -222,4 +222,10 @@
   virtual void       Draw(PIGraphicUC* g, double xmin, double ymin, double xmax, double ymax); 
 
+  inline void        ConfigureAxeTicks(int ntickx=0, int nticky=0, 
+				       double majtl=0., double mintl=0.)
+     { axeDr.ConfigureTicks(ntickx, nticky, majtl, mintl); }
+  inline void        ConfigureAxeAutoFontSize(double fszf=0.)
+     { axeDr.ConfigureAutoFontSize(fszf); }
+
   inline PIElDrwMgr& ElDrwMgr()    { return eltsMgr; }
 
@@ -251,4 +257,5 @@
   bool showAxesLabels;         // Affichage des labels d'axes si true
   bool fgClip;                 // Si true, appel a PIGraphicUC::Clip() ds Draw()
+  PIAxes axeDr;                // Trace d'axes
 };
 
Index: /trunk/SophyaPI/PI/pigraphgen.cc
===================================================================
--- /trunk/SophyaPI/PI/pigraphgen.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/pigraphgen.cc	(revision 2349)
@@ -504,5 +504,5 @@
   case PI_BasicArrowMarker :
     t0 = M_PI/4.;
-    asz = (double)myArrowMrkSz/cos(t0);
+    asz = (double)myArrowMrkSz/cos(t0)*0.75;
     tp = theta+0.75*M_PI;
     tm = theta-0.75*M_PI;
@@ -564,5 +564,5 @@
   default:
     t0 = M_PI/4.;
-    asz = (double)myArrowMrkSz/cos(t0);
+    asz = (double)myArrowMrkSz/cos(t0)*0.75;
     tp = theta+5.*M_PI/4.;
     tm = theta-5.*M_PI/4.;
Index: /trunk/SophyaPI/PI/piscdrawwdg.cc
===================================================================
--- /trunk/SophyaPI/PI/piscdrawwdg.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/piscdrawwdg.cc	(revision 2349)
@@ -92,5 +92,5 @@
   SetLimits(-1.,1.,-1.,1.,kAxeDirLtoR,kAxeDirDownUp);
   // SetDefaultDrawRectangle(0.12, 0.12, 0.88, 0.88, true); fait par SetAxesFlags() - Reza Mai 2002
-  SetAxesFlags(kBoxAxes | kExtTicks | kLabels);  
+  SetAxesFlags(kAxesDflt);
   FreeLimits();
   xEndDrag = yEndDrag = xBegDrag = yBegDrag = 0;
@@ -216,5 +216,5 @@
     SetDefaultDrawRectangle(0.13, 0.09, 0.93, 0.89, true);
   else 
-    SetDefaultDrawRectangle(0.06, 0.06, 0.94, 0.94, true);
+    SetDefaultDrawRectangle(0.08, 0.08, 0.92, 0.92, true);
 }
 
@@ -271,27 +271,6 @@
       continue;
     }
-    /*
-    les attributs d'axes sont decodes par PIElDrawer
-    if (opts == "simpleaxes")  {
-      SetAxesFlags(kAxesDflt);
-      continue;
-    }
-    if ( (opts == "stdaxes")  || (opts == "boxaxes") ) {
-      SetAxesFlags(kBoxAxes | kExtTicks | kLabels);
-      continue;
-    }
-    if (opts == "boxaxesgrid")  {
-      SetAxesFlags(kBoxAxes | kExtTicks | kLabels | kGridOn);
-      continue;
-    }
-    if (opts == "fineaxes")  {
-      SetAxesFlags(kBoxAxes | kTicks | kLabels | kMinTicks | kMajTicks);
-      continue;
-    }
-    if (opts == "fineaxesgrid")  {
-      SetAxesFlags(kBoxAxes | kTicks | kLabels | kMinTicks | kMajTicks | kGridOn);
-      continue;
-    }
-    */
+
+// Les attributs d'axes (stdaxes boxaxesgrid ...) sont decodes par PIElDrawer
 
     ndec--;
Index: /trunk/SophyaPI/PI/piscdrawwdg.h
===================================================================
--- /trunk/SophyaPI/PI/piscdrawwdg.h	(revision 2348)
+++ /trunk/SophyaPI/PI/piscdrawwdg.h	(revision 2349)
@@ -36,5 +36,5 @@
   virtual void	     UpdateLimits();  // Calcule et change les limites a partir de Drawer-No-1 
 
-  virtual void       SetAxesFlags(unsigned int flags=kBoxAxes | kExtTicks | kLabels);
+  virtual void       SetAxesFlags(unsigned int flags=kAxesDflt);
 
   inline void        SetTitles(string tt, string tb) 
Index: /trunk/SophyaPI/PI/piversion.h
===================================================================
--- /trunk/SophyaPI/PI/piversion.h	(revision 2348)
+++ /trunk/SophyaPI/PI/piversion.h	(revision 2349)
@@ -2,5 +2,5 @@
 #define PIVERSION_H_SEEN
 
-#define PI_VERSIONNUMBER  3.92
+#define PI_VERSIONNUMBER  3.93
 
 #endif

Index: /trunk/SophyaPI/PI/piaxes.cc
===================================================================
--- /trunk/SophyaPI/PI/piaxes.cc	(revision 2348)
+++ /trunk/SophyaPI/PI/piaxes.cc	(revision 2349)
@@ -39,4 +39,6 @@
 PIAxes::PIAxes()
 {
+  ConfigureTicks();
+  ConfigureAutoFontSize();
   setupDone = false;
 }
@@ -48,17 +50,20 @@
 
 //++
-// void  DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, unsigned int flags, bool afsz)
+// void  DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, \
+//                  unsigned int flags=kAxesDflt, bool afsz=true)
 //	Trace les axes en utilisant les limites de l'objet PIGraphicUC. 
 //	"flags" spécifie les attributs d'axes. Constantes prédéfinies: 
 //|	kStdAxes : Axes passant par le centre
 //|     kBoxAxes : Axes entourant le tracé
 //|	kIntTicks, kExtTicks
 //|	kMajTicks, kMinTicks
 //|	kAxesDflt = kStdAxes | kTicks | kLabels
 //|	kGridOn, kAxesNone
 //	Si "afsz == true", la taille de fonte est choisie automatiquement.
 //
-// void DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, unsigned int flags, bool afsz, \
-//      double xmin, double xmax, double ymin, double ymax)
+// void DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, \
+//        double xmin, double xmax, double ymin, double ymax, \
+//        unsigned int flags=kAxesDflt, bool afsz=true)
 //	Tracé d'axes avec spécification des limites d'axes.
 //
@@ -75,13 +80,19 @@
   PIGrCoord xmin, xmax, ymin, ymax;
   g->GetGrSpace(xmin, xmax, ymin, ymax);
-  DrawXYAxes(g, gratt, flags, afsz, (double)xmin, (double)xmax, 
-	     (double)ymin, (double)ymax);
+  DrawXYAxes(g, gratt, (double)xmin, (double)xmax, 
+	     (double)ymin, (double)ymax, flags, afsz);
 }
 
 /* --Methode-- */
 void PIAxes::DrawXYAxes(PIGraphicUC* g, PIGraphicAtt& gratt, 
-			unsigned int flags, bool afsz,
-			double xmin, double xmax, double ymin, double ymax)
-{
+			double xmin, double xmax, double ymin, double ymax,
+			unsigned int flags, bool afsz)
+
+{
+  if ((flags&kTicks)&&!(flags&kIntTicks)&&!(flags&kExtTicks))
+    flags |= kIntTicks;  // Ticks internes par defaut
+  if ((flags&kTicks)&&!(flags&kMajTicks)&&!(flags&kMinTicks))
+    flags |= kMajTicks;  // Ticks majeures par defaut
+  
   Setup(g, xmin, xmax, ymin, ymax);
   //  g->NoClip();
@@ -93,9 +104,9 @@
 
   if(afsz) { 
-    double fsz = xMajTickLen*3.5;
+    double fsz = (yMax-yMin)*fontSz;
     g->SelFontSz(fsz);
   }
 
-  if (flags & kStdAxes) {
+  if (flags & kCentAxes) {
 
     // Les axes
@@ -103,11 +114,12 @@
     g->DrawLine(xMin, (yMin+yMax)/2., xMax, (yMin+yMax)/2.);
     g->DrawLine((xMin+xMax)/2., yMin, (xMin+xMax)/2., yMax);
-    PIArrowMarker amk = g->GetArrowMarker();
-    if (amk == PI_NotDefArrowMarker) amk = PI_FArrowShapedArrowMarker;
+    //    PIArrowMarker amk = g->GetArrowMarker();
+    //    if (amk == PI_NotDefArrowMarker) 
+    PIArrowMarker amk =  amk = PI_FTriangleArrowMarker;
     g->SelArrowMarkerSz(xMajTickLen*2., amk);
     //    g->SelArrowMarker(5, g->GetArrowMarker());
-    double xm2 = g->DeltaUCX(xMax, yMajTickLen*3.);
+    double xm2 = g->DeltaUCX(xMax, yMajTickLen*2.);
     g->DrawArrowMarker(xMax, (yMin+yMax)/2., xm2, (yMin+yMax)/2., true);
-    double ym2 = g->DeltaUCY(yMax, xMajTickLen*3.);
+    double ym2 = g->DeltaUCY(yMax, xMajTickLen*2.);
     g->DrawArrowMarker((xMin+xMax)/2., yMax, (xMin+xMax)/2., ym2, true);
     // La grille en pointilles
@@ -132,12 +144,15 @@
     
     if (flags & kLabels) {
+      double declab = 2*xMajTickLen;
       if (!aYdir)
-        DrawHLabels(g, (yMin+yMax)/2.-xMajTickLen*2, xMajTicks, PI_VerticalTop);
+        DrawHLabels(g, (yMin+yMax)/2.-declab, xMajTicks, PI_VerticalTop);
       else 
-        DrawHLabels(g, (yMin+yMax)/2.+xMajTickLen*2, xMajTicks, PI_VerticalTop);
+        DrawHLabels(g, (yMin+yMax)/2.+declab, xMajTicks, PI_VerticalTop);
+
+      declab = 2.*yMajTickLen;
       if (!aXdir)
-        DrawVLabels(g, (xMin+xMax)/2.-yMajTickLen*2, yMajTicks, PI_HorizontalRight);
+        DrawVLabels(g, (xMin+xMax)/2.-declab, yMajTicks, PI_HorizontalRight);
       else 
-        DrawVLabels(g, (xMin+xMax)/2.+yMajTickLen*2, yMajTicks, PI_HorizontalRight);
+        DrawVLabels(g, (xMin+xMax)/2.+declab, yMajTicks, PI_HorizontalRight);
     }
     
@@ -154,5 +169,4 @@
 
     // Longueur des ticks
-    if (flags&kTicks) flags |= kExtTicks;
     double extXMajTickLen = flags&kExtTicks ? xMajTickLen : 0;
     double intXMajTickLen = flags&kIntTicks ? xMajTickLen : 0;
@@ -190,15 +204,19 @@
     
     if (flags & kLabels) {
+      double declab = xMajTickLen;
+      if (flags & kExtTicks) declab *= 2.;
       if (!aYdir) {
-        DrawHLabels(g, g->DeltaUCY(yMin, -xMajTickLen*2), xMajTicks, PI_VerticalTop);
+        DrawHLabels(g, g->DeltaUCY(yMin, -declab), xMajTicks, PI_VerticalTop);
       }
       else {
-        DrawHLabels(g, g->DeltaUCY(yMax,  xMajTickLen*2), xMajTicks, PI_VerticalTop);
+        DrawHLabels(g, g->DeltaUCY(yMax,  declab), xMajTicks, PI_VerticalTop);
       }
+      declab = yMajTickLen;
+      if (flags & kExtTicks) declab *= 2.;
       if (!aXdir) {
-        DrawVLabels(g, g->DeltaUCX(xMin, -yMajTickLen*2), yMajTicks, PI_HorizontalRight);
+        DrawVLabels(g, g->DeltaUCX(xMin, -declab), yMajTicks, PI_HorizontalRight);
       }
       else {
-        DrawVLabels(g, g->DeltaUCX(xMax,  yMajTickLen*2), yMajTicks, PI_HorizontalRight);
+        DrawVLabels(g, g->DeltaUCX(xMax,  declab), yMajTicks, PI_HorizontalRight);
       }
     }
@@ -275,4 +293,31 @@
 }
 
+//++
+// void ConfigureTicks(int ntickx=10, int nticky=12, \
+//		       double majtl=0.0125, double mintl=0.07)
+//	Configuration du nombre de ticks et taille des ticks.
+//	La taille des ticks est exprimée en fraction de la taille totale
+//	(X/Y max-min). Les paramètres ne sont pas changés si des valeurs
+//	négatives ou nulles sont spécifiées.
+// void ConfigureAutoFontSize(double fszf=0.0125)
+//	Configuration de la taille de fonte, en mode AutoFontSize.
+//	La taille est exprimée en fraction de la taille totale YMax-Min
+//--
+
+/* --Methode-- */
+void PIAxes::ConfigureTicks(int ntickx, int nticky, 
+			    double majtl, double mintl)
+{
+  if (ntickx > 0) xNTicks = ntickx;
+  if (nticky > 0) yNTicks = nticky;
+  if (majtl > 1.e-19) fMajTickLen = majtl;
+  if (mintl > 1.e-19) fMinTickLen = mintl;
+}
+/* --Methode-- */
+void PIAxes::ConfigureAutoFontSize(double fszf)
+{
+  if (fszf > 1.e-19) fontSz = fszf;
+}
+
 /* --Methode-- */
 void PIAxes::Setup(PIGraphicUC* g, double xmin, double xmax, 
@@ -288,16 +333,18 @@
   aYlog = g->isLogScaleY();
 
-  int ntick_x = (aXlog) ? 10 : 10;
+  //   Reza - Mars 03 - Nb de ticks en parametres
+  int ntick_x = (aXlog) ? xNTicks : xNTicks;
   if(aXlog) BestTicksLog(xMin,xMax,ntick_x,xMajTicks,xMinTicks);
   else BestTicks(xMin,xMax,ntick_x,xMajTicks,xMinTicks);
 
-  int ntick_y = (aYlog) ? 12 : 12;
+  int ntick_y = (aYlog) ? yNTicks : yNTicks;
   if(aYlog) BestTicksLog(yMin,yMax,ntick_y,yMajTicks,yMinTicks);
   else BestTicks(yMin,yMax,ntick_y,yMajTicks,yMinTicks);
 
-  yMajTickLen = (xMax-xMin)/100;
-  yMinTickLen = (xMax-xMin)/200;  // Au lieu de 250, Reza 20/10/02
-  xMajTickLen = (yMax-yMin)/100;
-  xMinTickLen = (yMax-yMin)/200;  // Au lieu de 250, Reza 20/10/02
+  //   Reza - Mars 03 - Taille des ticks en parametres
+  yMajTickLen = (xMax-xMin)*fMajTickLen;  // Au lieu de / 100  
+  yMinTickLen = (xMax-xMin)*fMinTickLen;  // Au lieu de / 200 ou 250
+  xMajTickLen = (yMax-yMin)*fMajTickLen;  // Au lieu de / 100
+  xMinTickLen = (yMax-yMin)*fMinTickLen;  // Au lieu de / 200 ou 250
 
   setupDone = true;
@@ -364,5 +411,5 @@
     if((aYdir && (just&PI_VerticalBottom)) || (!aYdir && (just&PI_VerticalTop))) h=-h; 
     double xm = (aXdir)? xMin: xMax;
-    double ym = g->DeltaUCY(y,1.5*h);
+    double ym = g->DeltaUCY(y,h);
     sprintf(label,"%d",npuiss);
     g->DrawCompString(xm,ym,"x 10",label,NULL,PI_HorizontalCenter|just);
@@ -405,5 +452,5 @@
   if(npuiss!=0) {
     if(aYdir) hauteur = -hauteur; 
-    double ym = (aYdir)? yMin: yMax; ym = g->DeltaUCY(ym,hauteur);
+    double ym = (aYdir)? yMin: yMax; ym = g->DeltaUCY(ym,0.5*hauteur);
     sprintf(label,"%d",npuiss);
     g->DrawCompString(x,ym,"x 10",label,NULL,PI_VerticalBottom|just);
@@ -48,17 +50,20 @@
 //	Trace les axes en utilisant les limites de l'objet PIGraphicUC. 
 //	"flags" spécifie les attributs d'axes. Constantes prédéfinies: 
-//|	kStdAxes : Axes passant par le centre
-//|     kBoxAxes : Axes entourant le tracé
+//|	kCentAxes : Axes passant par le centre
+//|     kBoxAxes  : Axes entourant le tracé
 //|	kIntTicks, kExtTicks
 //|	kMajTicks, kMinTicks
@@ -48,17 +50,20 @@
 //|	kIntTicks, kExtTicks
 //|	kMajTicks, kMinTicks
-//|	kAxesDflt = kStdAxes | kTicks | kLabels
+//|	kAxesDflt = kStdAxes =
+//|	      kBoxAxes | kTicks | | kIntTicks | kLabels
 //|	kGridOn, kAxesNone
 //	Si "afsz == true", la taille de fonte est choisie automatiquement.